@@ -4,11 +4,3 @@
 #                    (C) 2016, 2019-2020, 2022 Jeremy Brown                    #
 #                Released under Prosperity Public License 3.0.0                #
 ################################################################################
-
-from os.path import abspath, dirname, join
-
-
-module_root = dirname(abspath(__file__))
-
-with open(join(module_root, "VERSION"), encoding="utf-8") as version_file:
-    __version__ = version_file.read().strip()
